use strict;
use 5.005;

use ExtUtils::MakeMaker;
use File::Spec::Functions qw( catfile );

my $TEST_CONFIG_FILE = catfile('t', 'live.cfg');

warn <<EOW if $] < 5.006;

This version of PowerEdge::RAC has not been tested against perl v$]
The author welcomes patches if it does not work as is.

EOW

# These are required modules.
my %prereq = ('Digest::MD5'  => { version => 2.16,
				where => "CPAN/modules/by-module/Digest/Digest-MD5-x.x.tar.gz"},
			  'MIME::Base64' => { version => 2.12,
				where => "CPAN/modules/by-module/MIME/MIME-Base64-x.x.tar.gz"},
			  'LWP' 		 => { version => 5.53,
				where => "CPAN/modules/by-module/LWP/libwww-perl-x.x.tar.gz"},
			  'XML::Simple'  => { version => 1.08,
				where => "CPAN/modules/by-module/XML-Simple-x.x.tar.gz"},
			  'Crypt::SSLeay'  => { version => 0.43,
				where => "CPAN/modules/by-module/Crypt/Crypt-SSLeay-x.x.tar.gz"},
		 	 );

foreach (keys %prereq) {
	chk_version($_ => $prereq{$_}{version}) or
	warn  "\n"
		. "*** PowerEdge::RAC requires version $prereq{$_}{version} or later of $_\n"
		. "	from $prereq{$_}{where}\n\n";
	$prereq{$_} = $prereq{$_}{version};
}

setup_test_config();

WriteMakefile(
	'NAME'			=> 'PowerEdge::RAC',
	'DISTNAME'		=> 'PowerEdge-RAC',
	'VERSION_FROM'	=> 'lib/PowerEdge/RAC.pm', # finds $VERSION
	'PREREQ_PM'		=> \%prereq,
	'clean'			=> { 'FILES'		=>  't/live.cfg' },
	($] >= 5.005 ?	## Add these new keywords supported since 5.005
	 (ABSTRACT_FROM => 'lib/PowerEdge/RAC.pm', # retrieve abstract from module
	  AUTHOR		=> 'Harold van Oostrom <cpan@lanceerplaats.nl>') : ()),
);

sub chk_version
{
	my ($pkg, $wanted, $msg) = @_;

	local $| = 1;
	print "Checking for $pkg...";

	eval { eval "require $pkg" };

	my $vstr;
	my $vnum;
	{
	no strict 'refs';
	$vstr = ${"${pkg}::VERSION"} ? "found v".${"${pkg}::VERSION"} : "not found";
	$vnum = ${"${pkg}::VERSION"} || 0;
	}

	print $vnum >= $wanted ? "ok\n" : " " . $vstr . "\n";

	$vnum >= $wanted;
}

sub setup_test_config {
    my ($host, $user, $pass) = ('') x 3;
	my $RUN_LIVE_TEST = 'n';

    if (aprompt("Some of the tests require access to an existing RAC card.\n".
	       "I promise not to power_off() your server.\n".
	       "Do you want me to run the live tests ? ",
	       $RUN_LIVE_TEST) =~ /y/i) {

		$RUN_LIVE_TEST = 1;
        
		$host = aprompt('Enter the RAC card\'s IP address : ','192.168.0.120');
		$user = aprompt('Enter the RAC username  : ', 'root');
		$pass = aprompt('Enter the RAC password  : ', 'calvin');
    
		$user = 'root'   unless defined $user;
		$pass = 'calvin' unless defined $pass;
    } else {
        $RUN_LIVE_TEST = 0;
    }

    print("\nwriting $TEST_CONFIG_FILE\n");
    open(CFGFILE, ">$TEST_CONFIG_FILE") || die "$TEST_CONFIG_FILE: $!\n";
    print CFGFILE <<EOF;
\$run  = $RUN_LIVE_TEST;
\$host = '$host';
\$user = '$user';
\$pass = '$pass';
1;
EOF
    close(CFGFILE);
}

sub aprompt {
    my ($message, $default) = @_;
    my $ISA_TTY = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
    my $dispdef = defined $default ? "[$default] " : " ";
    $default = defined $default ? $default : "";
    my $answer = '';
    local $|=1;
    print "$message $dispdef";
    if (! $ISA_TTY) {
        print "$default\n";
    } else {
        chomp($answer = <STDIN>);
    };
    return ($answer ne '') ? $answer : $default;
};

