use strict;
use Test;
use vars qw($run $host $user $pass);
use lib './t';

BEGIN { $! =1 ; plan tests => 4 };

use PowerEdge::RAC;

# Check if the user wants the live tests by loading
# the configuration file that was created by Makefile.PL 
# It defines the $run, $host, $user and $pass variables.

require 'live.cfg';
unless ($run) {
	for(1 .. 4) { skip('Skipping on user request','', ''); }
    exit(0);
}

my $p = new PowerEdge::RAC(host => $host, user => $user, password => $pass);

my $sid;
eval { $sid = $p->establish_session(); };
if ($@ && $@ =~ /Protocol scheme/) {
	die << "EOF";
NOT OK

libwwww-perl doesn't appear to be able to handle https style URL's
Please install Crypt::SSLeay or Net::SSLeay and try again.

EOF
} elsif ($@) {
	warn << "EOF";
NOT OK

There was an error ($@) while trying to connect to the specified RAC card
with parameters (host = $host, username = $user, password = $pass)
Please verify that your cabling and network connection to this RAC are ok.
If necessary, re-run 'perl Makefile.PL' and specify new parameters
or or answer 'n' when prompted:

 Do you want to run the live test ?

EOF
	ok(0);
	exit(0);
} else {
	ok($sid, qr/0x/);
};

# Typical response: (192.168.1.5) at 00:06:5B:EC:98:12
ok($p->arp(), qr/ at /);

ok($p->sysinfo('System Model'), qr/PowerEdge/i);

# ok($p->power_status(), qr/Off|On/);

# Session id should still be the same ..
ok($p->session_id(), $sid);

